==> ZenTaoPMS.max2.0.rc1.php5.3_5.6.zip: zentaopms/module/upgrade/ext/config/zentaobiz.php <==
<?php
$config->bizVersion = array();
$config->bizVersion['biz1_0']      = '9_5_1';
$config->bizVersion['biz1_1']      = '9_6_3';
$config->bizVersion['biz1_1_1']    = '9_8';
$config->bizVersion['biz1_1_2']    = '9_8_1';
$config->bizVersion['biz1_1_3']    = '9_8_2';
$config->bizVersion['biz1_1_4']    = '9_8_3';
$config->bizVersion['biz2_0_beta'] = '10_0';
$config->bizVersion['biz2_1']      = '10_3';
$config->bizVersion['biz2_2']      = '10_4';
$config->bizVersion['biz2_3']      = '10_5';
$config->bizVersion['biz2_3_1']    = '10_6';
$config->bizVersion['biz2_4']      = '10_6';
$config->bizVersion['biz3_0']      = '11_1';
$config->bizVersion['biz3_1']      = '11_2';
$config->bizVersion['biz3_2']      = '11_3';
$config->bizVersion['biz3_2_1']    = '11_4_1';
$config->bizVersion['biz3_3']      = '11_5';
$config->bizVersion['biz3_4']      = '11_6';
$config->bizVersion['biz3_5_alpha']= '11_6';
$config->bizVersion['biz3_5_beta'] = '11_6_1';
$config->bizVersion['biz3_5']      = '11_6_5';
$config->bizVersion['biz3_5_1']    = '11_7';
$config->bizVersion['biz3_6']      = '12_0';
$config->bizVersion['biz3_6_1']    = '12_0_1';
$config->bizVersion['biz3_7']      = '12_2';
$config->bizVersion['biz3_7_1']    = '12_3_2';
$config->bizVersion['biz3_7_2']    = '12_3_3';
$config->bizVersion['biz4_0']      = '12_4';
$config->bizVersion['biz4_0_1']    = '12_4_1';
$config->bizVersion['biz4_0_2']    = '12_4_2';
$config->bizVersion['biz4_0_3']    = '12_4_3';
$config->bizVersion['biz4_0_4']    = '12_4_4';
$config->bizVersion['biz4_1']      = '12_5';
$config->bizVersion['biz4_1_1']    = '12_5_1';
$config->bizVersion['biz4_1_2']    = '12_5_2';
$config->bizVersion['biz4_1_3']    = '12_5_3';
$config->bizVersion['biz5_0_rc1']  = '15_0_rc3';

$config->excludeFiles['module/task/ext/control/create.php']      = 1;
$config->excludeFiles['module/execution/ext/control/kanban.php'] = 1;
$config->excludeFiles['module/task/ext/control/activate.php']  = 1;
$config->excludeFiles['module/task/ext/control/cancel.php']    = 1;
$config->excludeFiles['module/task/ext/control/close.php']     = 1;
$config->excludeFiles['module/task/ext/control/finish.php']    = 1;
$config->excludeFiles['module/task/ext/control/start.php']     = 1;

$config->delete['3.7'][]     = 'module/workflowlayout/ext/control/admin.php';
$config->delete['5.0.rc1'][] = 'module/attend/ext/control/setmanager.php';

$config->flowAction['batchedit']      = 'batchEdit';
$config->flowAction['batchcreate']    = 'batchCreate';
$config->flowAction['exporttemplate'] = 'exportTemplate';
$config->flowAction['showimport']     = 'showImport';
$config->flowAction['batchconfirm']   = 'batchConfirm';
$config->flowAction['batchresolve']   = 'batchResolve';
$config->flowAction['adminview']      = 'adminView';

==> ZenTaoPMS.max2.2.php7.2_7.4.zip: zentaopms/module/upgrade/ext/config/zentaobiz.php <==
<?php
$config->bizVersion = array();
$config->bizVersion['biz1_0']      = '9_5_1';
$config->bizVersion['biz1_1']      = '9_6_3';
$config->bizVersion['biz1_1_1']    = '9_8';
$config->bizVersion['biz1_1_2']    = '9_8_1';
$config->bizVersion['biz1_1_3']    = '9_8_2';
$config->bizVersion['biz1_1_4']    = '9_8_3';
$config->bizVersion['biz2_0_beta'] = '10_0';
$config->bizVersion['biz2_1']      = '10_3';
$config->bizVersion['biz2_2']      = '10_4';
$config->bizVersion['biz2_3']      = '10_5';
$config->bizVersion['biz2_3_1']    = '10_6';
$config->bizVersion['biz2_4']      = '10_6';
$config->bizVersion['biz3_0']      = '11_1';
$config->bizVersion['biz3_1']      = '11_2';
$config->bizVersion['biz3_2']      = '11_3';
$config->bizVersion['biz3_2_1']    = '11_4_1';
$config->bizVersion['biz3_3']      = '11_5';
$config->bizVersion['biz3_4']      = '11_6';
$config->bizVersion['biz3_5_alpha']= '11_6';
$config->bizVersion['biz3_5_beta'] = '11_6_1';
$config->bizVersion['biz3_5']      = '11_6_5';
$config->bizVersion['biz3_5_1']    = '11_7';
$config->bizVersion['biz3_6']      = '12_0';
$config->bizVersion['biz3_6_1']    = '12_0_1';
$config->bizVersion['biz3_7']      = '12_2';
$config->bizVersion['biz3_7_1']    = '12_3_2';
$config->bizVersion['biz3_7_2']    = '12_3_3';
$config->bizVersion['biz4_0']      = '12_4';
$config->bizVersion['biz4_0_1']    = '12_4_1';
$config->bizVersion['biz4_0_2']    = '12_4_2';
$config->bizVersion['biz4_0_3']    = '12_4_3';
$config->bizVersion['biz4_0_4']    = '12_4_4';
$config->bizVersion['biz4_1']      = '12_5';
$config->bizVersion['biz4_1_1']    = '12_5_1';
$config->bizVersion['biz4_1_2']    = '12_5_2';
$config->bizVersion['biz4_1_3']    = '12_5_3';
$config->bizVersion['biz5_0_rc1']  = '15_0_rc3';
$config->bizVersion['biz5_0']      = '15_0';
$config->bizVersion['biz5_0_1']    = '15_0_3';
$config->bizVersion['biz5_1']      = '15_3';
$config->bizVersion['biz5_2']      = '15_5';

$config->excludeFiles['module/task/ext/control/create.php']      = 1;
$config->excludeFiles['module/execution/ext/control/kanban.php'] = 1;
$config->excludeFiles['module/task/ext/control/activate.php']  = 1;
$config->excludeFiles['module/task/ext/control/cancel.php']    = 1;
$config->excludeFiles['module/task/ext/control/close.php']     = 1;
$config->excludeFiles['module/task/ext/control/finish.php']    = 1;
$config->excludeFiles['module/task/ext/control/start.php']     = 1;

$config->delete['3.7'][]     = 'module/workflowlayout/ext/control/admin.php';
$config->delete['5.0.rc1'][] = 'module/attend/ext/control/setmanager.php';
$config->delete['5.1'][]     = 'module/search/ext/model/hook/saveIndex.zentaobiz.hook.php';
$config->delete['5.1'][]     = 'module/doc/ext/view/view.html.php';

$config->flowAction['batchedit']      = 'batchEdit';
$config->flowAction['batchcreate']    = 'batchCreate';
$config->flowAction['exporttemplate'] = 'exportTemplate';
$config->flowAction['showimport']     = 'showImport';
$config->flowAction['batchconfirm']   = 'batchConfirm';
$config->flowAction['batchresolve']   = 'batchResolve';
$config->flowAction['adminview']      = 'adminView';
